# Utilities Module

The `wandas.utils` module provides various utility functions used in the Wandas library.

## Frame Dataset

Provides dataset utilities for managing multiple data frames.

::: wandas.utils.frame_dataset

## Sample Generation

Provides functions for generating sample data for testing.

::: wandas.utils.generate_sample

## Type Definitions

Provides type definitions used in Wandas.

::: wandas.utils.types

## General Utilities

Provides other general utility functions.

::: wandas.utils.util
